package FooTestFullPod;

use strict;
use warnings;

use Method::Signatures;

=head2 Methods

=over 2

=item new()

Some stuff

=cut

method new () {
}

=item foo()

Some stuff

=cut

method foo () {
	return 'foo';
}

=item bar()

Some stuff

=cut

method bar () {
	return 'bar';
}

=item baz()

Some stuff

=cut

method baz () {
	return 'baz';
}

=back

=cut

1;
